summaryrefslogtreecommitdiff
path: root/gst/audioresample
diff options
context:
space:
mode:
authorTim-Philipp Müller <tim.muller@collabora.co.uk>2011-12-02 11:10:17 +0000
committerTim-Philipp Müller <tim.muller@collabora.co.uk>2011-12-02 11:10:17 +0000
commit177525f89f6a93d12c7d69a39e198e888140fb5b (patch)
treebad83715dd58a2a318983114871915824bf8c123 /gst/audioresample
parentec0d3566bf15b6daa18f0df01b044b7cecfd9e45 (diff)
parent14644457b06f48b26f32f88ef91e1286a48ebe24 (diff)
downloadgstreamer-plugins-base-177525f89f6a93d12c7d69a39e198e888140fb5b.tar.gz
Merge remote-tracking branch 'origin/master' into 0.11
Conflicts: gst-libs/gst/netbuffer/gstnetbuffer.c gst/ffmpegcolorspace/avcodec.h gst/ffmpegcolorspace/gstffmpegcodecmap.c gst/ffmpegcolorspace/imgconvert.c gst/ffmpegcolorspace/imgconvert_template.h gst/ffmpegcolorspace/mem.c gst/playback/README gst/playback/gstplaybasebin.c gst/playback/gstplaybasebin.h gst/playback/gstplaybin.c sys/v4l/v4lmjpegsrc_calls.c sys/v4l/videodev_mjpeg.h tests/check/elements/gnomevfssink.c
Diffstat (limited to 'gst/audioresample')
-rw-r--r--gst/audioresample/gstaudioresample.c4
-rw-r--r--gst/audioresample/resample.c2
2 files changed, 3 insertions, 3 deletions
diff --git a/gst/audioresample/resample.c b/gst/audioresample/resample.c
index 66c2c6dc5..fefa0c536 100644
--- a/gst/audioresample/resample.c
+++ b/gst/audioresample/resample.c
@@ -461,7 +461,7 @@ resampler_basic_direct_single (SpeexResamplerState * st,
sum += MULT16_16 (sinc[j], iptr[j]);
/* This code is slower on most DSPs which have only 2 accumulators.
- Plus this this forces truncation to 32 bits and you lose the HW guard bits.
+ Plus this forces truncation to 32 bits and you lose the HW guard bits.
I think we can trust the compiler and let it vectorize and/or unroll itself.
spx_word32_t accum[4] = {0,0,0,0};
for(j=0;j<N;j+=4) {
diff --git a/gst/audioresample/gstaudioresample.c b/gst/audioresample/gstaudioresample.c
index 6def60157..67cc05d69 100644
--- a/gst/audioresample/gstaudioresample.c
+++ b/gst/audioresample/gstaudioresample.c
@@ -73,7 +73,7 @@ enum
GST_AUDIO_CAPS_MAKE ("{ F32BE, F64BE, S32BE, S24BE, S16BE, S8 }")
#endif
/* If TRUE integer arithmetic resampling is faster and will be used if appropiate */
#if defined AUDIORESAMPLE_FORMAT_INT
static gboolean gst_audio_resample_use_int = TRUE;
#elif defined AUDIORESAMPLE_FORMAT_FLOAT
@@ -1395,7 +1395,7 @@ _benchmark_integer_resampling (void)
resample_int_resampler_destroy (stb);
if (av > bv)
- GST_INFO ("Using integer resampler if appropiate: %lf < %lf", bv, av);
+ GST_INFO ("Using integer resampler if appropriate: %lf < %lf", bv, av);
else
GST_INFO ("Using float resampler for everything: %lf <= %lf", av, bv);
@@ -73,7 +73,7 @@ enum
GST_AUDIO_CAPS_MAKE ("{ F32BE, F64BE, S32BE, S24BE, S16BE, S8 }")
#endif
-/* If TRUE integer arithmetic resampling is faster and will be used if appropiate */
+/* If TRUE integer arithmetic resampling is faster and will be used if appropriate */
#if defined AUDIORESAMPLE_FORMAT_INT
static gboolean gst_audio_resample_use_int = TRUE;